/* MDM - The MDM Display Manager
 * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef GREETER_ITEM_PAM_H
#define GREETER_ITEM_PAM_H

#include "greeter_item.h"

gboolean greeter_item_pam_setup (void);
void greeter_item_pam_prompt (const char *message,
			      int         entry_len,
			      gboolean    entry_visible);
void greeter_item_pam_message (const char *message);
void greeter_item_pam_error (const char *message);
void greeter_item_pam_set_user (const char *user);
void greeter_item_pam_leftover_messages (void);
void greeter_item_pam_login (GtkEntry *entry, GreeterItemInfo *info);

extern gchar *greeter_current_user;

#endif
